@@ -23,7 +23,7 @@ class ErrorMessage:
 
     def to_dict(self) -> dict:
         return {
-            "id": self.id,
+            "id": str(self.id),
             "content": self.content,
             "source": self.source,
             "seconds_from_start": self.seconds_from_start,
