@@ -210,13 +210,13 @@ def _looks_like_llm_message_list(obj: Any) -> bool:
     return isinstance(sample, Mapping) and ("role" in sample and "content" in sample)
 
 
-def _extract_llm_messages_from_mappings(m: Mapping, max_depth: int = 2) -> Optional[Sequence[Mapping]]:
+def extract_llm_messages_from_mappings(m: Mapping, max_depth: int = 2) -> Optional[Sequence[Mapping]]:
     try:
         for k, v in m.items():
             if str(k).lower() == "messages" and _looks_like_llm_message_list(v):
                 return v
             if max_depth > 0 and isinstance(v, Mapping):
-                inner = _extract_llm_messages_from_mappings(v, max_depth - 1)
+                inner = extract_llm_messages_from_mappings(v, max_depth - 1)
                 if inner:
                     return inner
     except Exception:
@@ -601,7 +601,7 @@ def snapshot_processor(proc: Any, *, include_task_stacks: bool = True) -> Dict[s
 
     # heuristic LLM messages
     try:
-        llm_messages = _extract_llm_messages_from_mappings(getattr(proc, "__dict__", {}))
+        llm_messages = extract_llm_messages_from_mappings(getattr(proc, "__dict__", {}))
         if llm_messages:
             snap["llm_messages"] = _to_jsonable(llm_messages, max_depth=3)
     except Exception:
